@@ -44,6 +44,9 @@
   # compute fit indices
   fit_ind <- .gof(L, orig_R, N, "ML", ml$res$value)
 
+  # calculate model implied R
+  model_implied_R <- L %*% t(L) + diag(1 - h2)
+
   # create the output object
   class(L) <- "LOADINGS"
 
@@ -67,6 +70,7 @@
     unrot_loadings = L,
     vars_accounted = vars_accounted,
     fit_indices = fit_ind,
+    model_implied_R = model_implied_R,
     settings = settings
   )
 
